@@ -79,7 +79,7 @@ class Experiments(WMLResource):
             :returns: stored experiment details
             :rtype: dict
 
-           A way you might use me is:
+           **Example**
 
            >>> metadata = {
            >>>  client.experiments.ConfigurationMetaNames.NAME: 'my_experiment',
@@ -132,13 +132,20 @@ class Experiments(WMLResource):
         Updates existing experiment metadata.
 
         :param experiment_uid: UID of experiment which definition should be updated
-        :type experiment_uid: {str_type}
+        :type experiment_uid: str
 
         :param changes: elements which should be changed, where keys are ConfigurationMetaNames
         :type changes: dict
 
         :return: metadata of updated experiment
         :rtype: dict
+
+        **Example**
+         >>> metadata = {
+         >>> client.experiments.ConfigurationMetaNames.NAME:"updated_exp"
+         >>> }
+         >>> exp_details = client.experiments.update(experiment_uid, changes=metadata)
+
         """
         experiment_uid = str_type_conv(experiment_uid)
         self._validate_type(experiment_uid, u'experiment_uid', STR_TYPE, True)
@@ -188,14 +195,14 @@ class Experiments(WMLResource):
             Run experiment.
 
             :param experiment_uid: ID of stored experiment
-            :type experiment_uid: {str_type}
+            :type experiment_uid: str
             :param asynchronous: Default `True` means that experiment is started and progress can be checked later. `False` - method will wait till experiment end and print experiment stats.
             :type asynchronous: bool
 
             :return: experiment run details
             :rtype: dict
 
-            A way you might use me is
+            **Example**:
 
             >>> experiment_run_status = client.experiments.run(experiment_uid)
             >>> experiment_run_status = client.experiments.run(experiment_uid, asynchronous=False)
@@ -312,7 +319,7 @@ class Experiments(WMLResource):
             :returns: experiment status
             :rtype: dict
 
-            A way you might use me is
+            **Example**:
 
             >>> experiment_status = client.experiments.get_status(experiment_run_uid)
         """
@@ -338,7 +345,7 @@ class Experiments(WMLResource):
            :returns: experiment run metadata
            :rtype: dict
 
-           A way you might use me is
+           **Example**:
 
            >>> experiment_run_details = client.experiments.get_run_details(experiment_run_uid)
         """
@@ -361,15 +368,15 @@ class Experiments(WMLResource):
            Get metadata of experiment(s) run(s). If no experiment_uid is provided, runs will be listed for all existing experiments.
 
            :param experiment_uid:  experiment UID (optional)
-           :type experiment_uid: {str_type}
+           :type experiment_uid: str
 
            :param limit: limit number of fetched records (optional)
             :type limit: int
 
            :returns: experiment(s) run(s) metadata
-           :rtype: dict
+           :rtype: dict (if uid is not None) or {"resources": [dict]} (if uid is None)
 
-           A way you might use me is
+           **Example**:
 
            >>> experiment_details = client.experiments.get_details(experiment_uid)
            >>> experiment_details = client.experiments.get_details()
@@ -387,9 +394,9 @@ class Experiments(WMLResource):
             :type experiment_details: dict
 
             :returns: uid of stored experiment
-            :rtype: {str_type}
+            :rtype: str
 
-            A way you might use me is:
+            **Example**
 
             >>> experiment_uid = client.experiments.get_uid(experiment_details)
         """
@@ -409,9 +416,9 @@ class Experiments(WMLResource):
             :type experiment_details: dict
 
             :returns: url of stored experiment
-            :rtype: {str_type}
+            :rtype: str
 
-            A way you might use me is:
+            **Example**
 
             >>> experiment_url = client.experiments.get_url(experiment_details)
         """
@@ -431,9 +438,9 @@ class Experiments(WMLResource):
             :type experiment_run_details: object
 
             :returns: experiment run url
-            :rtype: {str_type}
+            :rtype: str
 
-            A way you might use me is
+            **Example**:
 
             >>> experiment_run_url = client.experiments.get_run_url(experiment_run_details)
         """
@@ -461,9 +468,9 @@ class Experiments(WMLResource):
             :type experiment_run_details: object
 
             :returns: experiment run uid
-            :rtype: {str_type}
+            :rtype: str
 
-            A way you might use me is
+            **Example**:
 
             >>> experiment_run_uid = client.experiments.get_run_uid(experiment_run_details)
         """
@@ -491,7 +498,7 @@ class Experiments(WMLResource):
             :returns: training runs
             :rtype: array
 
-            A way you might use me is
+            **Example**:
 
             >>> training_runs = client.experiments.get_training_runs(experiment_run_details)
         """
@@ -520,7 +527,7 @@ class Experiments(WMLResource):
             :returns: training uids
             :rtype: array
 
-            A way you might use me is
+            **Example**:
 
             >>> training_uids = client.experiments.get_training_uids(experiment_run_details)
         """
@@ -545,9 +552,12 @@ class Experiments(WMLResource):
             Delete experiment run.
 
             :param experiment_run_uid:  experiment run UID
-            :type experiment_run_uid: {str_type}
+            :type experiment_run_uid: str
 
-            A way you might use me is
+            :returns: returns the status message ("SUCCESS" or FAILED")
+            :rtype: str
+
+            **Example**:
 
             >>> client.experiments.delete(experiment_run_uid)
 
@@ -566,7 +576,7 @@ class Experiments(WMLResource):
 
         response = requests.delete(run_url, headers=self._client._get_headers())
 
-        self._handle_response(204, u'experiment deletion', response, False)
+        return self._handle_response(204, u'experiment deletion', response, False)
 
     def _get_extended_details(self, experiment_uid=None, extended=True):
         experiment_uid = str_type_conv(experiment_uid)
@@ -621,12 +631,18 @@ class Experiments(WMLResource):
             List experiment runs. If experiment_uid set to None and limit set to None only 50 first records will be displayed.
 
             :param experiment_uid: experiment UID (optional)
-            :type experiment_uid: {str_type}
+            :type experiment_uid: str
 
             :param limit: limit number of fetched records (optional)
             :type limit: int
 
-            A way you might use me is
+            :returns: None
+            :rtype: None
+
+            .. note::
+               This function only prints the list of experiments-runs
+
+            **Example**:
 
             >>> client.experiments.list_runs()
             >>> client.experiments.list_runs(experiment_uid)
@@ -654,9 +670,15 @@ class Experiments(WMLResource):
              List training runs triggered by experiment run.
 
              :param experiment_run_uid: experiment run UID
-             :type experiment_run_uid: {str_type}
+             :type experiment_run_uid: str
 
-             A way you might use me is
+             :returns: None
+             :rtype: None
+
+             .. note::
+               This function only prints the list of training-runs associated with an experiment-run.
+
+             **Example**:
 
              >>> client.experiments.list_training_runs(experiment_run_uid)
         """
@@ -680,9 +702,9 @@ class Experiments(WMLResource):
             Monitor experiment run log files (prints log content to console).
 
             :param experiment_run_uid: ID of experiment run
-            :type experiment_run_uid: {str_type}
+            :type experiment_run_uid: str
 
-            A way you might use me is
+            **Example**:
 
             >>> client.experiments.monitor_logs(experiment_run_uid)
         """
@@ -784,9 +806,9 @@ class Experiments(WMLResource):
             Monitor metrics log file (prints metrics to console).
 
             :param experiment_run_uid: ID of experiment run
-            :type run_uid: {str_type}
+            :type run_uid: str
 
-            A way you might use me is:
+            **Example**
 
             >>> client.experiments.monitor_metrics(experiment_run_uid)
         """
@@ -799,18 +821,28 @@ class Experiments(WMLResource):
 
         print_text_header_h1(u'Metric monitor started for experiment run: ' + str(experiment_run_uid))
 
-        from lomond import WebSocket
-        experiment_monitor_endpoint = self._wml_credentials[u'url'].replace(u'https',
+        run_details = self.get_run_details(experiment_run_uid)
+
+        status = run_details["entity"]["experiment_run_status"]["state"]
+        if (status == "completed" or status == "error" or status=="failed" or status=="canceled"):
+
+         training_statuses = run_details["entity"]["training_statuses"]
+         for each_training_run in range(len(training_statuses)):
+             self._client.training._COS_metrics(training_statuses[each_training_run]["training_guid"], lambda: print_text_header_h1('Metric monitor started for training run: ' + str(training_statuses[each_training_run]["training_guid"])))
+
+        else:
+         from lomond import WebSocket
+         experiment_monitor_endpoint = self._wml_credentials[u'url'].replace(u'https',
                                                                      u'wss') + u'/v3/experiments/' + experiment_uid + u'/runs/' + experiment_run_uid + '/monitor'
-        websocket = WebSocket(experiment_monitor_endpoint)
-        try:
+         websocket = WebSocket(experiment_monitor_endpoint)
+         try:
             websocket.add_header(bytes('Authorization', 'utf-8'), bytes('bearer ' + self._client.service_instance._get_token(), 'utf-8'))
-        except:
+         except:
             websocket.add_header(bytes('Authorization'), bytes('bearer ' + self._client.service_instance._get_token()))
 
-        previous_guid = u''
+         previous_guid = u''
 
-        for event in websocket:
+         for event in websocket:
             if event.name == u'text':
                 text = json.loads(event.text)
                 if (u'entity' in str(text)) and (u'training_statuses' in str(text)):
@@ -846,9 +878,9 @@ class Experiments(WMLResource):
 
                                         previous_guid = guid
 
-        websocket.close()
+         websocket.close()
 
-        print_text_header_h2(u'Metric monitor done.')
+         print_text_header_h2(u'Metric monitor done.')
 
     def get_latest_metrics(self, experiment_run_uid):
         """
@@ -860,7 +892,7 @@ class Experiments(WMLResource):
              :returns: metric values
              :rtype: list of dicts
 
-             A way you might use me is:
+             **Example**
 
              >>> client.experiments.get_latest_metrics(experiment_run_uid)
          """
@@ -894,7 +926,7 @@ class Experiments(WMLResource):
               :returns: metric values
               :rtype: list of dicts
 
-              A way you might use me is:
+              **Example**
 
               >>> client.experiments.get_metrics(experiment_run_uid)
         """
@@ -917,7 +949,13 @@ class Experiments(WMLResource):
         """
            List stored experiments. If limit is set to None there will be only first 50 records shown.
 
-           A way you might use me is
+           :returns: None
+           :rtype: None
+
+           .. note::
+               This function only prints the list of experiments
+
+           **Example**:
 
            >>> client.experiments.list_definitions()
         """
@@ -930,7 +968,7 @@ class Experiments(WMLResource):
             Get metadata of stored experiments. If neither experiment uid nor url is specified all experiments metadata is returned.
 
             :param experiment_uid: stored experiment UID (optional)
-            :type experiment_uid: {str_type}
+            :type experiment_uid: str
 
             :param limit: limit number of fetched records (optional)
             :type limit: int
@@ -938,7 +976,7 @@ class Experiments(WMLResource):
             :returns: stored experiment(s) metadata
             :rtype: dict
 
-            A way you might use me is:
+            **Example**
 
             >>> experiment_details = client.experiments.get_definition_details(experiment_uid)
             >>> experiment_details = client.experiments.get_definition_details()
@@ -955,9 +993,9 @@ class Experiments(WMLResource):
             :type experiment_details: dict
 
             :returns: uid of stored experiment
-            :rtype: {str_type}
+            :rtype: str
 
-            A way you might use me is:
+            **Example**
 
             >>> experiment_uid = client.experiments.get_definition_uid(experiment_details)
         """
@@ -972,9 +1010,9 @@ class Experiments(WMLResource):
             :type experiment_details: dict
 
             :returns: url of stored experiment
-            :rtype: {str_type}
+            :rtype: str
 
-            A way you might use me is:
+            **Example**
 
             >>> experiment_url = client.experiments.get_definition_url(experiment_details)
         """
