@@ -18,6 +18,10 @@ from watson_machine_learning_client.wml_client_error import WMLClientError
 from watson_machine_learning_client.href_definitions import is_uid
 from watson_machine_learning_client.wml_resource import WMLResource
 
+from botocore.exceptions import ClientError
+from ibm_boto3.exceptions import Boto3Error
+
+
 
 class Training(WMLResource):
     """
@@ -43,9 +47,9 @@ class Training(WMLResource):
            Get list of supported frameworks.
 
            :returns: supported frameworks for training
-           :rtype: json
+           :rtype: dict
 
-           A way you might use me is:
+           **Example**
 
            >>> model_details = client.training.get_frameworks()
         """
@@ -63,12 +67,12 @@ class Training(WMLResource):
               Get training status.
 
               :param run_uid: ID of trained model
-              :type run_uid: {str_type}
+              :type run_uid: str
 
               :returns: training run status
               :rtype: dict
 
-              A way you might use me is:
+              **Example**
 
               >>> training_status = client.training.get_status(run_uid)
         """
@@ -88,15 +92,15 @@ class Training(WMLResource):
               Get training run details.
 
               :param run_uid: ID of training run (optional, if not provided all runs details are returned)
-              :type run_uid: {str_type}
+              :type run_uid: str
 
               :param limit: limit number of fetched records (optional)
               :type limit: int
 
               :returns: training run(s) details
-              :rtype: dict
+              :rtype: dict (if uid is not None) or {"resources": [dict]} (if uid is None)
 
-              A way you might use me is:
+              **Example**
 
               >>> training_run_details = client.training.get_details(run_uid)
               >>> training_runs_details = client.training.get_details()
@@ -118,9 +122,9 @@ class Training(WMLResource):
             :type run_details: dict
 
             :returns: training run URL that is used to manage the training
-            :rtype: {str_type}
+            :rtype: str
 
-            A way you might use me is:
+            **Example**
 
             >>> run_url = client.training.get_run_url(run_details)
         """
@@ -138,9 +142,9 @@ class Training(WMLResource):
             :type run_details: dict
 
             :returns: uid of training run
-            :rtype: {str_type}
+            :rtype: str
 
-            A way you might use me is:
+            **Example**
 
             >>> model_uid = client.training.get_run_uid(run_details)
         """
@@ -154,9 +158,9 @@ class Training(WMLResource):
               Cancel model training.
 
               :param run_uid: ID of trained model
-              :type run_uid: {str_type}
+              :type run_uid: str
 
-              A way you might use me is:
+              **Example**
 
               >>> client.training.cancel(run_uid)
         """
@@ -183,7 +187,7 @@ class Training(WMLResource):
         Train new model.
 
         :param definition_uid: uid to saved model_definition/pipeline
-        :type definition_uid: {str_type}
+        :type definition_uid: str
 
         :param meta_props: meta data of the training configuration. To see available meta names use:
 
@@ -198,7 +202,7 @@ class Training(WMLResource):
         :returns: training run details
         :rtype: dict
 
-        A way you might use me is:
+        **Example**
 
         >>> metadata = {
         >>>  client.training.ConfigurationMetaNames.NAME: u'Hand-written Digit Recognition',
@@ -330,7 +334,13 @@ class Training(WMLResource):
         """
            List training runs. If limit is set to None there will be only first 50 records shown.
 
-           A way you might use me is:
+           :returns: None
+           :rtype: None
+
+           .. note::
+               This function only prints the list of training runs
+
+           **Example**
 
            >>> client.training.list()
         """
@@ -348,9 +358,12 @@ class Training(WMLResource):
             Delete training run.
 
             :param run_uid: ID of trained model
-            :type run_uid: {str_type}
+            :type run_uid: str
 
-            A way you might use me is:
+            :returns: returns the status message ("SUCCESS" or FAILED")
+            :rtype: str
+
+            **Example**
 
             >>> client.training.delete(run_uid)
         """
@@ -360,7 +373,7 @@ class Training(WMLResource):
         response_delete = requests.delete(self._href_definitions.get_repo_model_href(run_uid),
                                           headers=self._client._get_headers())
 
-        self._handle_response(204, u'trained model deletion', response_delete, False)
+        return self._handle_response(204, u'trained model deletion', response_delete, False)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def monitor_logs(self, run_uid):
@@ -368,9 +381,9 @@ class Training(WMLResource):
             Monitor training log file (prints log content to console).
 
             :param run_uid: ID of trained model
-            :type run_uid: {str_type}
+            :type run_uid: str
 
-            A way you might use me is:
+            **Example**
 
             >>> client.training.monitor_logs(run_uid)
         """
@@ -381,31 +394,106 @@ class Training(WMLResource):
 
         print_text_header_h2('Log monitor done.')
 
-    def _simple_monitor_logs(self, run_uid, on_start=lambda: {}):
-        from lomond import WebSocket
-
-        monitor_endpoint = self._wml_credentials[u'url'].replace(u'https',
-                                                                 u'wss') + u'/v3/models/' + run_uid + u'/monitor'
-        websocket = WebSocket(monitor_endpoint)
-        try:
-            websocket.add_header(bytes("Authorization", "utf-8"), bytes("bearer " + self._client.service_instance._get_token(), "utf-8"))
-        except:
-            websocket.add_header(bytes("Authorization"), bytes("bearer " + self._client.service_instance._get_token()))
-
+    def _COS_logs(self, run_uid,on_start=lambda: {}):
         on_start()
+        run_details = self.get_details(run_uid)
+        endpoint_url = run_details["entity"]["training_results_reference"]["connection"]["endpoint_url"]
+        if("networklayer" in endpoint_url):
+            endpoint_url = endpoint_url.replace("service.networklayer.com","softlayer.net")
+        aws_access_key = run_details["entity"]["training_results_reference"]["connection"]["access_key_id"]
+        aws_secret = run_details["entity"]["training_results_reference"]["connection"]["secret_access_key"]
+        bucket = run_details["entity"]["training_results_reference"]["location"]["bucket"]
+        try:
+            run_details["entity"]["training_results_reference"]["location"]["model_location"]
+        except:
+            raise WMLClientError("The training-run has not started. Error - " + run_details["entity"]["status"]["error"]["errors"][0]["message"])
 
-        for event in websocket:
-            if event.name == u'text':
-                text = json.loads(event.text)
+        if (bucket == ""):
+            bucket = run_details["entity"]["training_results_reference"]["target"]["bucket"]
+        import ibm_boto3
 
-                if 'status' in text:
-                    status = text[u'status']
+        client_cos = ibm_boto3.client(service_name='s3', aws_access_key_id=aws_access_key,
+                                      aws_secret_access_key=aws_secret,
+                                      endpoint_url=endpoint_url)
 
-                    if u'message' in status:
-                        if len(status[u'message']) > 0:
-                            print(status[u'message'])
+        try:
+            key = run_details["entity"]["training_results_reference"]["location"]["model_location"] + '/learner-1/training-log.txt'
+            obj = client_cos.get_object(Bucket=bucket, Key=key)
+            print(obj['Body'].read().decode('utf-8'))
+        except ibm_boto3.exceptions.ibm_botocore.client.ClientError as ex:
+            if ex.response['Error']['Code'] == 'NoSuchKey':
+                print("ERROR - Cannot find training-log.txt in the bucket")
+            else:
+                print(ex)
 
-        websocket.close()
+    def _COS_metrics(self, run_uid,on_start=lambda: {}):
+        on_start()
+        run_details = self.get_details(run_uid)
+        endpoint_url = run_details["entity"]["training_results_reference"]["connection"]["endpoint_url"]
+        if("networklayer" in endpoint_url):
+            endpoint_url = endpoint_url.replace("service.networklayer.com","softlayer.net")
+        aws_access_key = run_details["entity"]["training_results_reference"]["connection"]["access_key_id"]
+        aws_secret = run_details["entity"]["training_results_reference"]["connection"]["secret_access_key"]
+        bucket = run_details["entity"]["training_results_reference"]["location"]["bucket"]
+        try:
+            run_details["entity"]["training_results_reference"]["location"]["model_location"]
+        except:
+            raise WMLClientError("The training-run has not started. Error - " + run_details["entity"]["status"]["error"]["errors"][0]["message"])
+
+        if (bucket == ""):
+            bucket = run_details["entity"]["training_results_reference"]["target"]["bucket"]
+        import ibm_boto3
+        client_cos = ibm_boto3.client(service_name='s3', aws_access_key_id=aws_access_key,
+                                      aws_secret_access_key=aws_secret,
+                                      endpoint_url=endpoint_url)
+        try:
+            key = run_details["entity"]["training_results_reference"]["location"]["model_location"] + '/learner-1/evaluation-metrics.txt'
+            obj = client_cos.get_object(Bucket=bucket, Key=key)
+            print(obj['Body'].read().decode('utf-8'))
+        except ibm_boto3.exceptions.ibm_botocore.client.ClientError as ex:
+            if ex.response['Error']['Code'] == 'NoSuchKey':
+                print("ERROR - Cannot find evaluation-metrics.txt in the bucket")
+            else:
+                print(ex)
+
+    def _simple_monitor_logs(self, run_uid, on_start=lambda: {}):
+        run_details = self.get_details(run_uid)
+        status = run_details["entity"]["status"]["state"]
+
+        if (status == "completed" or status == "error" or status == "failed" or status == "canceled"):
+            self._COS_logs(run_uid,
+                           lambda: print_text_header_h1(u'Log monitor started for training run: ' + str(run_uid)))
+        else:
+
+            from lomond import WebSocket
+
+            monitor_endpoint = self._wml_credentials[u'url'].replace(u'https',
+                                                                     u'wss') + u'/v3/models/' + run_uid + u'/monitor'
+            websocket = WebSocket(monitor_endpoint)
+            try:
+                websocket.add_header(bytes("Authorization", "utf-8"), bytes("bearer " + self._client.service_instance._get_token(), "utf-8"))
+            except:
+                websocket.add_header(bytes("Authorization"), bytes("bearer " + self._client.service_instance._get_token()))
+            if 'apikey' in self._wml_credentials.keys():
+                try:
+                    websocket.add_header(bytes('ML-Instance-ID', 'utf-8'), bytes(self._wml_credentials['instance_id'],"utf-8"))
+                except:
+                    websocket.add_header(bytes('ML-Instance-ID'), bytes(self._wml_credentials['instance_id']))
+
+            on_start()
+
+            for event in websocket:
+                if event.name == u'text':
+                    text = json.loads(event.text)
+
+                    if 'status' in text:
+                        status = text[u'status']
+
+                        if u'message' in status:
+                            if len(status[u'message']) > 0:
+                                print(status[u'message'])
+
+            websocket.close()
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def monitor_metrics(self, run_uid):
@@ -413,44 +501,56 @@ class Training(WMLResource):
             Monitor metrics log file (prints log content to console).
 
             :param run_uid: ID of trained model
-            :type run_uid: {str_type}
+            :type run_uid: str
 
-            A way you might use me is:
+            **Example**
 
             >>> client.training.monitor_metrics(run_uid)
         """
         run_uid = str_type_conv(run_uid)
         Training._validate_type(run_uid, u'run_uid', STR_TYPE, True)
+        run_details = self.get_details(run_uid)
+        status = run_details["entity"]["status"]["state"]
+        if (status == "completed" or status == "error" or status == "failed" or status == "canceled"):
+            self._COS_metrics(run_uid,
+                              lambda: print_text_header_h1('Metric monitor started for training run: ' + str(run_uid)))
+            print_text_header_h2('Metric monitor done.')
+        else:
+            from lomond import WebSocket
 
-        from lomond import WebSocket
+            monitor_endpoint = self._wml_credentials[u'url'].replace(u'https',
+                                                                     u'wss') + u'/v3/models/' + run_uid + u'/monitor'
+            websocket = WebSocket(monitor_endpoint)
+            try:
+                websocket.add_header(bytes("Authorization", "utf-8"), bytes("bearer " + self._client.service_instance._get_token(), "utf-8"))
+            except:
+                websocket.add_header(bytes("Authorization"), bytes("bearer " + self._client.service_instance._get_token()))
+            if 'apikey' in self._wml_credentials.keys():
+                try:
+                    websocket.add_header(bytes('ML-Instance-ID', 'utf-8'), bytes(self._wml_credentials['instance_id'],"utf-8"))
+                except:
+                    websocket.add_header(bytes('ML-Instance-ID'), bytes(self._wml_credentials['instance_id']))
 
-        monitor_endpoint = self._wml_credentials[u'url'].replace(u'https',
-                                                                 u'wss') + u'/v3/models/' + run_uid + u'/monitor'
-        websocket = WebSocket(monitor_endpoint)
-        try:
-            websocket.add_header(bytes("Authorization", "utf-8"), bytes("bearer " + self._client.service_instance._get_token(), "utf-8"))
-        except:
-            websocket.add_header(bytes("Authorization"), bytes("bearer " + self._client.service_instance._get_token()))
+            print_text_header_h1('Metric monitor started for training run: ' + str(run_uid))
 
-        print_text_header_h1('Metric monitor started for training run: ' + str(run_uid))
+            for event in websocket:
+                if event.name == u'text':
+                    text = json.loads(event.text)
+                    status = text[u'status']
+                    if u'metrics' in status:
+                        metrics = status[u'metrics']
+                        if len(metrics) > 0:
+                            metric = metrics[0]
+                            values = u''
+                            for x in metric[u'values']:
+                                values = values + x[u'name'] + ':' + str(x[u'value']) + u' '
+                            msg = u'{} iteration:{} phase:{} {}'.format(metric[u'timestamp'], metric[u'iteration'], metric[u'phase'], values)
+                            print(msg)
 
-        for event in websocket:
-            if event.name == u'text':
-                text = json.loads(event.text)
-                status = text[u'status']
-                if u'metrics' in status:
-                    metrics = status[u'metrics']
-                    if len(metrics) > 0:
-                        metric = metrics[0]
-                        values = u''
-                        for x in metric[u'values']:
-                            values = values + x[u'name'] + ':' + str(x[u'value']) + u' '
-                        msg = u'{} iteration:{} phase:{} {}'.format(metric[u'timestamp'], metric[u'iteration'], metric[u'phase'], values)
-                        print(msg)
+            websocket.close()
 
-        websocket.close()
+            print_text_header_h2('Metric monitor done.')
 
-        print_text_header_h2('Metric monitor done.')
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_metrics(self, run_uid):
@@ -458,12 +558,12 @@ class Training(WMLResource):
              Get metrics values.
 
              :param run_uid: ID of trained model
-             :type run_uid: {str_type}
+             :type run_uid: str
 
              :returns: metric values
              :rtype: list of dicts
 
-             A way you might use me is:
+             **Example**
 
              >>> client.training.get_metrics(run_uid)
          """
@@ -486,7 +586,7 @@ class Training(WMLResource):
              :returns: metric values
              :rtype: list of dicts
 
-             A way you might use me is:
+             **Example**
 
              >>> client.training.get_latest_metrics(run_uid)
          """
@@ -511,7 +611,13 @@ class Training(WMLResource):
         """
            List stored definitions. If limit is set to None there will be only first 50 records shown.
 
-           A way you might use me is
+           :returns: None
+           :rtype: None
+
+           .. note::
+               This function only prints the list of stored training-definitions
+
+           **Example**:
 
            >>> client.training.list_definitions()
         """
@@ -523,7 +629,7 @@ class Training(WMLResource):
             Get metadata of stored definitions. If definition uid is not specified returns all model definitions metadata.
 
             :param definition_uid:  stored model definition UID (optional)
-            :type definition_uid: {str_type}
+            :type definition_uid: str
 
             :param limit: limit number of fetched records (optional)
             :type limit: int
@@ -531,7 +637,7 @@ class Training(WMLResource):
             :returns: stored definition(s) metadata
             :rtype: dict
 
-            A way you might use me is:
+            **Example**
 
             >>> definition_details = client.training.get_definition_details(definition_uid)
             >>> definition_details = client.training.get_definition_details()
@@ -548,7 +654,7 @@ class Training(WMLResource):
             :returns: uid of stored model
             :rtype: str
 
-            A way you might use me is:
+            **Example**
 
             >>> definition_uid = client.training.get_definition_uid(definition_details)
         """
@@ -563,9 +669,9 @@ class Training(WMLResource):
             :type definition_details: dict
 
             :returns: url of stored definition
-            :rtype: {str_type}
+            :rtype: str
 
-            A way you might use me is:
+            **Example**
 
             >>> definition_url = client.training.get_definition_url(definition_details)
         """
