@@ -25,10 +25,22 @@ class WMLResource:
         wml_token = str_type_conv(client.wml_token)
         WMLResource._validate_type(wml_token, u'wml_token', STR_TYPE, True)
         self._client = client
-        self._wml_credentials = client.wml_credentials
-        self._href_definitions = HrefDefinitions(client.wml_credentials)
+        self._ICP = client.ICP
+
+        if not client.ICP:
+            self._wml_credentials = client.wml_credentials
+            self._href_definitions = HrefDefinitions(client.wml_credentials)
+        else:
+            self._wml_credentials = client.service_instance._wml_credentials
+            self._href_definitions = HrefDefinitions(client.service_instance._wml_credentials)
 
     def _handle_response(self, expected_status_code, operationName, response, json_response=True):
+        if "dele" in operationName:
+            if response.status_code == expected_status_code:
+                return "SUCCESS"
+            else:
+                print(response.text)
+                return "FAILED"
         if response.status_code == expected_status_code:
             self._logger.info(u'Successfully finished {} for url: \'{}\''.format(operationName, response.url))
             self._logger.debug(u'Response({} {}): {}'.format(response.request.method, response.url, response.text))
@@ -132,10 +144,17 @@ class WMLResource:
 
             url = base_url + u'/' + uid
 
-            response_get = requests.get(
-                url,
-                headers=self._client._get_headers()
-            )
+            if not self._ICP:
+                response_get = requests.get(
+                    url,
+                    headers=self._client._get_headers()
+                )
+            else:
+                response_get = requests.get(
+                    url,
+                    headers=self._client._get_headers(),
+                    verify=False
+                )
 
             return self._handle_response(200, op_name, response_get)
 
@@ -148,21 +167,36 @@ class WMLResource:
 
             params = {u'limit': limit}
 
-            response_get = requests.get(
-                url,
-                headers=self._client._get_headers(),
-                params=params
-            )
+            if not self._ICP:
+                response_get = requests.get(
+                    url,
+                    headers=self._client._get_headers(),
+                    params=params
+                )
+            else:
+                response_get = requests.get(
+                    url,
+                    headers=self._client._get_headers(),
+                    params=params,
+                    verify=False
+                )
 
             return self._handle_response(200, op_name, response_get)
         else:
             resources = []
 
             while True:
-                response_get = requests.get(
-                    url,
-                    headers=self._client._get_headers()
-                )
+                if not self._ICP:
+                    response_get = requests.get(
+                        url,
+                        headers=self._client._get_headers()
+                    )
+                else:
+                    response_get = requests.get(
+                        url,
+                        headers=self._client._get_headers(),
+                        verify=False
+                    )
 
                 result = self._handle_response(200, op_name, response_get)
 
@@ -192,21 +226,3 @@ class WMLResource:
         else:
             table = tabulate([header] + values)
             print(table)
-
-    def _validate_plan(self, operation_name, list_of_expected_plans):
-        plan_names_mapping = {
-            'ais-enterprise': 'enterprise',
-            'enterpriseAIS': 'enterprise'
-        }
-
-        def map_plan_name(plan_name):
-            if plan_name in plan_names_mapping.keys():
-                return plan_names_mapping[plan_name]
-            else:
-                return plan_name
-
-        actual_plan = self._client.service_instance.details['entity']['plan']
-        if not actual_plan in list_of_expected_plans:
-            actual_plan = map_plan_name(actual_plan)
-            list_of_expected_plans = list(set([map_plan_name(plan_name) for plan_name in list_of_expected_plans]))
-            raise ForbiddenActionForPlan(operation_name, list_of_expected_plans, actual_plan)
